@@ -24,9 +24,9 @@ import ssl
 import sys
 import threading
 import time
+from urllib import parse
 import uuid
 
-from amqp import exceptions as amqp_exec
 import kombu
 import kombu.connection
 import kombu.entity
@@ -35,9 +35,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import eventletutils
 from oslo_utils import importutils
-import six
-import six.moves
-from six.moves.urllib import parse
 
 import oslo_messaging
 from oslo_messaging._drivers import amqp as rpc_amqp
@@ -60,7 +57,7 @@ else:
     # we will facing an issue by trying to override the threading module.
     stdlib_threading = threading
 
-# NOTE(sileht): don't exists in py2 socket module
+# NOTE(sileht): don't exist in py2 socket module
 TCP_USER_TIMEOUT = 18
 
 rabbit_opts = [
@@ -175,11 +172,6 @@ rabbit_opts = [
                'for direct send. The direct send is used as reply, '
                'so the MessageUndeliverable exception is raised '
                'in case the client queue does not exist.'),
-    cfg.BoolOpt('enable_cancel_on_failover',
-                default=False,
-                help="Enable x-cancel-on-ha-failover flag so that "
-                     "rabbitmq server will cancel and notify consumers"
-                     "when queue is down")
 ]
 
 LOG = logging.getLogger(__name__)
@@ -241,8 +233,7 @@ class Consumer(object):
 
     def __init__(self, exchange_name, queue_name, routing_key, type, durable,
                  exchange_auto_delete, queue_auto_delete, callback,
-                 nowait=False, rabbit_ha_queues=None, rabbit_queue_ttl=0,
-                 enable_cancel_on_failover=False):
+                 nowait=False, rabbit_ha_queues=None, rabbit_queue_ttl=0):
         """Init the Consumer class with the exchange_name, routing_key,
         type, durable auto_delete
         """
@@ -264,16 +255,10 @@ class Consumer(object):
             type=type,
             durable=self.durable,
             auto_delete=self.exchange_auto_delete)
-        self.enable_cancel_on_failover = enable_cancel_on_failover
 
     def declare(self, conn):
         """Re-declare the queue after a rabbit (re)connect."""
 
-        consumer_arguments = None
-        if self.enable_cancel_on_failover:
-            consumer_arguments = {
-                "x-cancel-on-ha-failover": True}
-
         self.queue = kombu.entity.Queue(
             name=self.queue_name,
             channel=conn.channel,
@@ -281,9 +266,7 @@ class Consumer(object):
             durable=self.durable,
             auto_delete=self.queue_auto_delete,
             routing_key=self.routing_key,
-            queue_arguments=self.queue_arguments,
-            consumer_arguments=consumer_arguments
-        )
+            queue_arguments=self.queue_arguments)
 
         try:
             LOG.debug('[%s] Queue.declare: %s',
@@ -335,7 +318,7 @@ class Consumer(object):
             self.declare(conn)
         try:
             self.queue.consume(callback=self._callback,
-                               consumer_tag=six.text_type(tag),
+                               consumer_tag=str(tag),
                                nowait=self.nowait)
         except conn.connection.channel_errors as exc:
             # We retries once because of some races that we can
@@ -355,14 +338,14 @@ class Consumer(object):
                                    exc.method_name == 'Basic.ack'):
                 self.declare(conn)
                 self.queue.consume(callback=self._callback,
-                                   consumer_tag=six.text_type(tag),
+                                   consumer_tag=str(tag),
                                    nowait=self.nowait)
             else:
                 raise
 
     def cancel(self, tag):
         LOG.trace('ConsumerBase.cancel: canceling %s', tag)
-        self.queue.cancel(six.text_type(tag))
+        self.queue.cancel(str(tag))
 
     def _callback(self, message):
         """Call callback with deserialized message.
@@ -484,7 +467,6 @@ class Connection(object):
         self.kombu_failover_strategy = driver_conf.kombu_failover_strategy
         self.kombu_compression = driver_conf.kombu_compression
         self.heartbeat_in_pthread = driver_conf.heartbeat_in_pthread
-        self.enable_cancel_on_failover = driver_conf.enable_cancel_on_failover
 
         if self.heartbeat_in_pthread:
             # NOTE(hberaud): Experimental: threading module is in use to run
@@ -769,7 +751,7 @@ class Connection(object):
             info = {'err_str': exc, 'sleep_time': interval}
             info.update(self._get_connection_info(conn_error=True))
 
-            if 'Socket closed' in six.text_type(exc):
+            if 'Socket closed' in str(exc):
                 LOG.error('[%(connection_id)s] AMQP server'
                           ' %(hostname)s:%(port)s closed'
                           ' the connection. Check login credentials:'
@@ -883,8 +865,8 @@ class Connection(object):
         """Close/release this connection."""
         self._heartbeat_stop()
         if self.connection:
-            for consumer in six.moves.filter(lambda c: c.type == 'fanout',
-                                             self._consumers):
+            for consumer in filter(lambda c: c.type == 'fanout',
+                                   self._consumers):
                 LOG.debug('[connection close] Deleting fanout '
                           'queue: %s ' % consumer.queue.name)
                 consumer.queue.delete()
@@ -1028,8 +1010,7 @@ class Connection(object):
                     except (socket.timeout,
                             ConnectRefuseError,
                             OSError,
-                            kombu.exceptions.OperationalError,
-                            amqp_exec.ConnectionForced) as exc:
+                            kombu.exceptions.OperationalError) as exc:
                         LOG.info("A recoverable connection/channel error "
                                  "occurred, trying to reconnect: %s", exc)
                         self.ensure_connection()
@@ -1135,35 +1116,31 @@ class Connection(object):
         responses for call/multicall
         """
 
-        consumer = Consumer(
-            exchange_name='',  # using default exchange
-            queue_name=topic,
-            routing_key='',
-            type='direct',
-            durable=False,
-            exchange_auto_delete=False,
-            queue_auto_delete=False,
-            callback=callback,
-            rabbit_ha_queues=self.rabbit_ha_queues,
-            rabbit_queue_ttl=self.rabbit_transient_queues_ttl,
-            enable_cancel_on_failover=self.enable_cancel_on_failover)
+        consumer = Consumer(exchange_name='',  # using default exchange
+                            queue_name=topic,
+                            routing_key='',
+                            type='direct',
+                            durable=False,
+                            exchange_auto_delete=False,
+                            queue_auto_delete=False,
+                            callback=callback,
+                            rabbit_ha_queues=self.rabbit_ha_queues,
+                            rabbit_queue_ttl=self.rabbit_transient_queues_ttl)
 
         self.declare_consumer(consumer)
 
     def declare_topic_consumer(self, exchange_name, topic, callback=None,
                                queue_name=None):
         """Create a 'topic' consumer."""
-        consumer = Consumer(
-            exchange_name=exchange_name,
-            queue_name=queue_name or topic,
-            routing_key=topic,
-            type='topic',
-            durable=self.amqp_durable_queues,
-            exchange_auto_delete=self.amqp_auto_delete,
-            queue_auto_delete=self.amqp_auto_delete,
-            callback=callback,
-            rabbit_ha_queues=self.rabbit_ha_queues,
-            enable_cancel_on_failover=self.enable_cancel_on_failover)
+        consumer = Consumer(exchange_name=exchange_name,
+                            queue_name=queue_name or topic,
+                            routing_key=topic,
+                            type='topic',
+                            durable=self.amqp_durable_queues,
+                            exchange_auto_delete=self.amqp_auto_delete,
+                            queue_auto_delete=self.amqp_auto_delete,
+                            callback=callback,
+                            rabbit_ha_queues=self.rabbit_ha_queues)
 
         self.declare_consumer(consumer)
 
@@ -1174,18 +1151,16 @@ class Connection(object):
         exchange_name = '%s_fanout' % topic
         queue_name = '%s_fanout_%s' % (topic, unique)
 
-        consumer = Consumer(
-            exchange_name=exchange_name,
-            queue_name=queue_name,
-            routing_key=topic,
-            type='fanout',
-            durable=False,
-            exchange_auto_delete=True,
-            queue_auto_delete=False,
-            callback=callback,
-            rabbit_ha_queues=self.rabbit_ha_queues,
-            rabbit_queue_ttl=self.rabbit_transient_queues_ttl,
-            enable_cancel_on_failover=self.enable_cancel_on_failover)
+        consumer = Consumer(exchange_name=exchange_name,
+                            queue_name=queue_name,
+                            routing_key=topic,
+                            type='fanout',
+                            durable=False,
+                            exchange_auto_delete=True,
+                            queue_auto_delete=False,
+                            callback=callback,
+                            rabbit_ha_queues=self.rabbit_ha_queues,
+                            rabbit_queue_ttl=self.rabbit_transient_queues_ttl)
 
         self.declare_consumer(consumer)
 
@@ -1309,7 +1284,7 @@ class Connection(object):
                 # the 404 kombu ChannelError and retry until the exchange
                 # appears
                 raise rpc_amqp.AMQPDestinationNotFound(
-                    "exchange %s doesn't exists" % exchange.name)
+                    "exchange %s doesn't exist" % exchange.name)
             raise
 
     def direct_send(self, msg_id, msg):
