@@ -22,7 +22,7 @@ import logging
 import sys
 import threading
 
-import six
+from oslo_utils import eventletutils
 
 from oslo_messaging import _utils as utils
 from oslo_messaging import dispatcher
@@ -81,8 +81,7 @@ class UnsupportedVersion(RPCDispatcherError):
         self.method = method
 
 
-@six.add_metaclass(ABCMeta)
-class RPCAccessPolicyBase(object):
+class RPCAccessPolicyBase(object, metaclass=ABCMeta):
     """Determines which endpoint methods may be invoked via RPC"""
 
     @abstractmethod
@@ -249,7 +248,7 @@ class RPCDispatcher(dispatcher.DispatcherBase):
         # is executing if it runs for some time. The thread will wait
         # for the event to be signaled, which we do explicitly below
         # after dispatching the method call.
-        completion_event = threading.Event()
+        completion_event = eventletutils.Event()
         watchdog_thread = threading.Thread(target=self._watchdog,
                                            args=(completion_event, incoming))
         if incoming.client_timeout:
